---
layout: docs
seotitle: NLP | John Snow Labs
title: John Snow Labs Release Notes
permalink: /docs/en/jsl/jsl-release-notes
key: docs-install
modify_date: "2020-05-26"
header: true
show_nav: true
sidebar:
    nav: jsl
---

<div class="main-docs" markdown="1">

See [Github Releases](https://github.com/JohnSnowLabs/johnsnowlabs/releases) for detailed information on Release History and Features




## 5.2.4
Release date: 1-2-2023

The John Snow Labs 5.2.4 Library released with the following pre-installed and recommended dependencies


| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.1.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.2.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.1.4` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.2.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |



## 5.2.3
Release date: 31-1-2023

The John Snow Labs 5.2.3 Library released with the following pre-installed and recommended dependencies


| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.1.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.2.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.1.4` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.2.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |



## 5.2.2
Release date: 22-1-2023

The John Snow Labs 5.2.2 Library released with the following pre-installed and recommended dependencies


| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.1.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.2.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.1.3` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.2.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |

## 5.2.1
Release date: 20-1-2023

The John Snow Labs 5.2.1 Library released with the following pre-installed and recommended dependencies


| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.1.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.2.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.1.3` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.2.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |



## 5.2.0
Release date: 4-1-2023

The John Snow Labs 5.2.0 Library released with the following pre-installed and recommended dependencies


| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.1.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.2.0` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.1.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.2.0` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |

## 5.1.9
Release date: 5-12-2023

The John Snow Labs 5.1.9 Library released with the following pre-installed and recommended dependencies


| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.1.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.1.4` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.1.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.1.4` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |


## 5.1.8
Release date: 17-11-2023

The John Snow Labs 5.1.8 Library released with the following pre-installed and recommended dependencies


| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.0.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.1.3` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.1.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.1.4` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |

## 5.1.7
Release date: 19-10-2023

The John Snow Labs 5.1.6 Library released with the following pre-installed and recommended dependencies


| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.0.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.1.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.0.3` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.1.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |




## 5.1.6
Release date: 11-10-2023

The John Snow Labs 5.1.6 Library released with the following pre-installed and recommended dependencies



| Library                                                                                 | Version |
|-----------------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes) | `5.0.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)              | `5.1.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes)             | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)                   | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                                     | `5.0.3` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)                               | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                        | `5.1.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                             | `3.1.2` |




## 5.1.5
Release date: 9-10-2023

The John Snow Labs 5.1.5 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.1` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.1.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.3` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.1.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |




## 5.1.4
Release date: 8-10-2023

The John Snow Labs 5.1.4 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.1` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.1.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.2` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.1.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |


## 5.1.3
Release date: 6-10-2023

The John Snow Labs 5.1.3 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.1` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.1.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.1` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.1.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |




## 5.1.2
Release date: 4-10-2023

The John Snow Labs 5.1.2 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.1` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.1.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.1` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.1.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |



## 5.1.1
Release date: 1-10-2023

The John Snow Labs 5.1.1 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.1` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.1.0` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.1` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.1.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |



## 5.1.0
Release date: 25-09-2023

The John Snow Labs 5.1.0 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.1` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.1.0` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.1` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.1.0` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |


## 5.0.9
Release date: 11-09-2023

The John Snow Labs 5.0.9 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.1` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |


## 5.0.8
Release date: 10-09-2023

The John Snow Labs 5.0.8 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.1` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |



## 5.0.7
Release date: 03-09-2023

The John Snow Labs 5.0.7 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.1` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |





## 5.0.8
Release date: 11-09-2023

The John Snow Labs 5.0.5 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/jsl/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/jsl/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/jsl/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/jsl/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.1` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/jsl/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |





## 5.0.7
Release date: 3-09-2023

The John Snow Labs 5.0.5 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/jsl/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/jsl/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/jsl/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/jsl/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.0` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/jsl/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |




## 5.0.6
Release date: 03-09-2023

The John Snow Labs 5.0.6 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |




## 5.0.5
Release date: 25-08-2023

The John Snow Labs 5.0.5 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |




## 5.0.4
Release date: 23-08-2023

The John Snow Labs 5.0.4 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |



## 5.0.3
Release date: 23-08-2023

The John Snow Labs 5.0.3 Library released with the following pre-installed and recommended dependencies


| Library                                                                         | Version |
|---------------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `5.0.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                             | `5.0.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)                | `5.0.2` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                     | `3.1.2` |

## 5.0.1
Release date: 02-08-2023

The John Snow Labs 5.0.1 Library released with the following pre-installed and recommended dependencies


| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.4` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.2` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `5.0.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |




## 5.0.0
Release date: 13-07-2023

The John Snow Labs 5.0.0 Library released with the following pre-installed and recommended dependencies


| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.3` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `5.0.0` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.2` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `5.0.0` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |





## 4.4.11
Release date: 11-07-2023

The John Snow Labs 4.4.11 Library released with the following pre-installed and recommended dependencies


| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.3` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.4` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.2` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.4` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |




## 4.4.10
Release date: 04-07-2023

The John Snow Labs 4.4.10 Library released with the following pre-installed and recommended dependencies


| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.3` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.4` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.2` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.4` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |




## 4.4.9
Release date: 04-07-2023

The John Snow Labs 4.4.9 Library released with the following pre-installed and recommended dependencies


| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.3` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.4` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.2` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.4`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |



## 4.4.8
Release date: 14-06-2023

The John Snow Labs 4.4.8 Library released with the following pre-installed and recommended dependencies


| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.3` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.2` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.1`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |



## 4.4.7
Release date: 06-06-2023

The John Snow Labs 4.4.7 Library released with the following pre-installed and recommended dependencies


| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.2` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.3` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.1` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.1`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |





## 4.4.6
Release date: 28-05-2023

The John Snow Labs 4.4.6 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.1` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.2` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.1`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |



- `create_jsl_home_if_missing` parameter added to `nlp.start()` which can be set to `False` to disable the creation of the
  `~/.johnsnowlabs` directory. This is useful when jars are provided directly via `jar_paths` parameter.

- Dynamic Wheel resolution for spark nlp, enabling you to set
  settings.nlp_version='4.4.2' and it will automatically use the appropriate  jars and wheels when
  starting a session or building an envirornment.


- Bump Enterprise NLP version to 4.4.2
- Bump OCR version to 4.4.1

- Fixed erronous handling of enterprise-secrets which have
  `<VERSION>.<PR-NUM>.<COMMIT_HASH>` pattern,

## 4.4.5
Release date: 03-05-2023

The John Snow Labs 4.4.5 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.1` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.1`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |




## 4.4.4
Release date: 26-04-2023

The John Snow Labs 4.4.4 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.0` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://sparknlp.org/docs/en/display)           | `4.1`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |





## 4.4.3
Release date: 26-04-2023

The John Snow Labs 4.4.3 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version |
|-----------------------------------------------------------------------------|---------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.0` |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.0` |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X` |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X` |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`   |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.1` |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2` |

## 4.4.2
Release date: 18-04-2023

The John Snow Labs 4.4.2 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.4.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.0`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.4.1
Release date: 13-04-2023

The John Snow Labs 4.4.1 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.3`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.0`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.4.0
Release date: 12-04-2023

The John Snow Labs 4.4.0 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.3`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.4.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.4.0`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.3.5
Release date: 25-03-2023

The John Snow Labs 4.3.5 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.3`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.3.2`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.3.2`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.3.4
Release date: 20-03-2023

The John Snow Labs 4.3.4 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.3`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.3.1`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.2.0` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.3.2`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.3.3
Release date: 23-02-2023

The John Snow Labs 4.3.3 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.1`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.3.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc6` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.3.0`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.3.2
Release date: 21-02-2023

The John Snow Labs 4.3.2 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.3.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc6` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.3.0`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.3.1
Release date: 14-02-2023

The John Snow Labs 4.3.1 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.3.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc5` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.3.0`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.3.0
Release date: 14-02-2023

The John Snow Labs 4.3.0 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.3.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.3.0`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.2.9
Release date: 01-02-2023

The John Snow Labs 4.2.9 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.2.8`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.2.8`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.2.8
Release date: 29-01-2023

The John Snow Labs 4.2.8 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.3.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.2.8`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.2.8`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |

## 4.2.5
Release date: 27-12-2022

The John Snow Labs 4.2.5 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.2.4`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.2.4`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.2.4`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |


## 4.2.4
Release date: 21-12-2022

The John Snow Labs 4.2.4 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.2.1`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.2.4`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.2.4`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |


## 4.2.3
Release date: 02-12-2022

The John Snow Labs 4.2.3 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.2.1`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.2.3`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.2.4`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |


## 4.2.2
Release date: 17-10-2022

The John Snow Labs 4.2.2 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.2.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.2.2`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.2.2`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |


## 4.2.1
Release date: 10-10-2022

The John Snow Labs 4.2.1 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.1.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.2.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.2.1`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |



## 4.2.0 
Release date: 06-10-2022

The John Snow Labs 4.2.0 Library released with the following pre-installed and recommended dependencies

| Library                                                                     | Version    |
|-----------------------------------------------------------------------------|------------|
| [Visual NLP](https://nlp.johnsnowlabs.com/docs/en/spark_ocr_versions/ocr_release_notes)        | `4.0.0`    |
| [Enterprise NLP](https://nlp.johnsnowlabs.com/docs/en/licensed_annotators)  | `4.2.0`    |
| [Finance NLP](https://nlp.johnsnowlabs.com/docs/en/financial_release_notes) | `1.X.X`    |
| [Legal NLP](https://nlp.johnsnowlabs.com/docs/en/legal_release_notes)       | `1.X.X`    |
| [NLU](https://github.com/JohnSnowLabs/nlu/releases)                         | `4.0.1rc4` |
| [Spark-NLP-Display](https://nlp.johnsnowlabs.com/docs/en/display)           | `4.1`      |
| [Spark-NLP](https://github.com/JohnSnowLabs/spark-nlp/releases/)            | `4.2.0`    |
| [Pyspark](https://spark.apache.org/docs/latest/api/python/)                 | `3.1.2`    |


</div>
